package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class AttributeCertificateInfo extends ASN1Encodable {
   private DERInteger version;
   private Holder holder;
   private AttCertIssuer issuer;
   private AlgorithmIdentifier signature;
   private DERInteger serialNumber;
   private AttCertValidityPeriod attrCertValidityPeriod;
   private ASN1Sequence attributes;
   private DERBitString issuerUniqueID;
   private X509Extensions extensions;

   public static AttributeCertificateInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static AttributeCertificateInfo getInstance(Object obj) {
      if (obj instanceof AttributeCertificateInfo) {
         return (AttributeCertificateInfo)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new AttributeCertificateInfo((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public AttributeCertificateInfo(ASN1Sequence seq) {
      if (seq.size() >= 7 && seq.size() <= 9) {
         this.version = DERInteger.getInstance(seq.getObjectAt(0));
         this.holder = Holder.getInstance(seq.getObjectAt(1));
         this.issuer = AttCertIssuer.getInstance(seq.getObjectAt(2));
         this.signature = AlgorithmIdentifier.getInstance(seq.getObjectAt(3));
         this.serialNumber = DERInteger.getInstance(seq.getObjectAt(4));
         this.attrCertValidityPeriod = AttCertValidityPeriod.getInstance(seq.getObjectAt(5));
         this.attributes = ASN1Sequence.getInstance(seq.getObjectAt(6));

         for(int var2 = 7; var2 < seq.size(); ++var2) {
            ASN1Encodable var3;
            if ((var3 = (ASN1Encodable)seq.getObjectAt(var2)) instanceof DERBitString) {
               this.issuerUniqueID = DERBitString.getInstance(seq.getObjectAt(var2));
            } else if (var3 instanceof ASN1Sequence || var3 instanceof X509Extensions) {
               this.extensions = X509Extensions.getInstance(seq.getObjectAt(var2));
            }
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public Holder getHolder() {
      return this.holder;
   }

   public AttCertIssuer getIssuer() {
      return this.issuer;
   }

   public AlgorithmIdentifier getSignature() {
      return this.signature;
   }

   public DERInteger getSerialNumber() {
      return this.serialNumber;
   }

   public AttCertValidityPeriod getAttrCertValidityPeriod() {
      return this.attrCertValidityPeriod;
   }

   public ASN1Sequence getAttributes() {
      return this.attributes;
   }

   public DERBitString getIssuerUniqueID() {
      return this.issuerUniqueID;
   }

   public X509Extensions getExtensions() {
      return this.extensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.holder);
      var1.add(this.issuer);
      var1.add(this.signature);
      var1.add(this.serialNumber);
      var1.add(this.attrCertValidityPeriod);
      var10001.add(this.attributes);
      DERBitString var2;
      if ((var2 = this.issuerUniqueID) != null) {
         var1.add(var2);
      }

      X509Extensions var3;
      if ((var3 = this.extensions) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
